# A simple example on how to use Flit

This module is just a "Hello, world!" example for publishing package with [Flit](https://flit.pypa.io/).

## Installation

```
pip install tomboulier_foobar
```

## Usage

``` bash
$ python -m tomboulier_foobar          
Hello, world!
```